==> jbpm-serverless-workflow-0.9.1-sources.jar: org/jbpm/serverless/workflow/api/events/EventsActions.java <==

package org.jbpm.serverless.workflow.api.events;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonValue;
import org.jbpm.serverless.workflow.api.actions.Action;
import org.jbpm.serverless.workflow.api.filters.EventDataFilter;


/**
 * Actions to be performed on Events arrival
 * 
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "eventRefs",
    "actionMode",
    "actions",
    "eventDataFilter"
})
public class EventsActions implements Serializable
{

    /**
     * References one or more unique event names in the defined workflow events
     * (Required)
     * 
     */
    @JsonProperty("eventRefs")
    @JsonPropertyDescription("References one or more unique event names in the defined workflow events")
    @Valid
    @NotNull
    private List<String> eventRefs = new ArrayList<String>();
    /**
     * Specifies how actions are to be performed (in sequence of parallel)
     * 
     */
    @JsonProperty("actionMode")
    @JsonPropertyDescription("Specifies how actions are to be performed (in sequence of parallel)")
    private EventsActions.ActionMode actionMode = EventsActions.ActionMode.fromValue("SEQUENTIAL");
    /**
     * Actions to be performed.
     * (Required)
     * 
     */
    @JsonProperty("actions")
    @JsonPropertyDescription("Actions to be performed.")
    @Valid
    @NotNull
    private List<Action> actions = new ArrayList<Action>();
    @JsonProperty("eventDataFilter")
    @Valid
    private EventDataFilter eventDataFilter;
    private final static long serialVersionUID = 7026517811213702597L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public EventsActions() {
    }

    /**
     * 
     * @param eventRefs
     * @param actions
     */
    public EventsActions(List<String> eventRefs, List<Action> actions) {
        super();
        this.eventRefs = eventRefs;
        this.actions = actions;
    }

    /**
     * References one or more unique event names in the defined workflow events
     * (Required)
     * 
     */
    @JsonProperty("eventRefs")
    public List<String> getEventRefs() {
        return eventRefs;
    }

    /**
     * References one or more unique event names in the defined workflow events
     * (Required)
     * 
     */
    @JsonProperty("eventRefs")
    public void setEventRefs(List<String> eventRefs) {
        this.eventRefs = eventRefs;
    }

    public EventsActions withEventRefs(List<String> eventRefs) {
        this.eventRefs = eventRefs;
        return this;
    }

    /**
     * Specifies how actions are to be performed (in sequence of parallel)
     * 
     */
    @JsonProperty("actionMode")
    public EventsActions.ActionMode getActionMode() {
        return actionMode;
    }

    /**
     * Specifies how actions are to be performed (in sequence of parallel)
     * 
     */
    @JsonProperty("actionMode")
    public void setActionMode(EventsActions.ActionMode actionMode) {
        this.actionMode = actionMode;
    }

    public EventsActions withActionMode(EventsActions.ActionMode actionMode) {
        this.actionMode = actionMode;
        return this;
    }

    /**
     * Actions to be performed.
     * (Required)
     * 
     */
    @JsonProperty("actions")
    public List<Action> getActions() {
        return actions;
    }

    /**
     * Actions to be performed.
     * (Required)
     * 
     */
    @JsonProperty("actions")
    public void setActions(List<Action> actions) {
        this.actions = actions;
    }

    public EventsActions withActions(List<Action> actions) {
        this.actions = actions;
        return this;
    }

    @JsonProperty("eventDataFilter")
    public EventDataFilter getEventDataFilter() {
        return eventDataFilter;
    }

    @JsonProperty("eventDataFilter")
    public void setEventDataFilter(EventDataFilter eventDataFilter) {
        this.eventDataFilter = eventDataFilter;
    }

    public EventsActions withEventDataFilter(EventDataFilter eventDataFilter) {
        this.eventDataFilter = eventDataFilter;
        return this;
    }

    public enum ActionMode {

        SEQUENTIAL("SEQUENTIAL"),
        PARALLEL("PARALLEL");
        private final String value;
        private final static Map<String, EventsActions.ActionMode> CONSTANTS = new HashMap<String, EventsActions.ActionMode>();

        static {
            for (EventsActions.ActionMode c: values()) {
                CONSTANTS.put(c.value, c);
            }
        }

        private ActionMode(String value) {
            this.value = value;
        }

        @Override
        public String toString() {
            return this.value;
        }

        @JsonValue
        public String value() {
            return this.value;
        }

        @JsonCreator
        public static EventsActions.ActionMode fromValue(String value) {
            EventsActions.ActionMode constant = CONSTANTS.get(value);
            if (constant == null) {
                throw new IllegalArgumentException(value);
            } else {
                return constant;
            }
        }

    }

}

==> jbpm-serverless-workflow-0.13.0-sources.jar: org/jbpm/serverless/workflow/api/events/EventsActions.java <==

package org.jbpm.serverless.workflow.api.events;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonValue;
import org.jbpm.serverless.workflow.api.actions.Action;
import org.jbpm.serverless.workflow.api.filters.EventDataFilter;


/**
 * Actions to be performed on Events arrival
 * 
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "eventRefs",
    "actionMode",
    "actions",
    "eventDataFilter"
})
public class EventsActions implements Serializable
{

    /**
     * References one or more unique event names in the defined workflow events
     * (Required)
     * 
     */
    @JsonProperty("eventRefs")
    @JsonPropertyDescription("References one or more unique event names in the defined workflow events")
    @Valid
    @NotNull
    private List<String> eventRefs = new ArrayList<String>();
    /**
     * Specifies how actions are to be performed (in sequence of parallel)
     * 
     */
    @JsonProperty("actionMode")
    @JsonPropertyDescription("Specifies how actions are to be performed (in sequence of parallel)")
    private EventsActions.ActionMode actionMode = EventsActions.ActionMode.fromValue("sequential");
    /**
     * Actions to be performed.
     * (Required)
     * 
     */
    @JsonProperty("actions")
    @JsonPropertyDescription("Actions to be performed.")
    @Valid
    @NotNull
    private List<Action> actions = new ArrayList<Action>();
    @JsonProperty("eventDataFilter")
    @Valid
    private EventDataFilter eventDataFilter;
    private final static long serialVersionUID = 7026517811213702597L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public EventsActions() {
    }

    /**
     * 
     * @param eventRefs
     * @param actions
     */
    public EventsActions(List<String> eventRefs, List<Action> actions) {
        super();
        this.eventRefs = eventRefs;
        this.actions = actions;
    }

    /**
     * References one or more unique event names in the defined workflow events
     * (Required)
     * 
     */
    @JsonProperty("eventRefs")
    public List<String> getEventRefs() {
        return eventRefs;
    }

    /**
     * References one or more unique event names in the defined workflow events
     * (Required)
     * 
     */
    @JsonProperty("eventRefs")
    public void setEventRefs(List<String> eventRefs) {
        this.eventRefs = eventRefs;
    }

    public EventsActions withEventRefs(List<String> eventRefs) {
        this.eventRefs = eventRefs;
        return this;
    }

    /**
     * Specifies how actions are to be performed (in sequence of parallel)
     * 
     */
    @JsonProperty("actionMode")
    public EventsActions.ActionMode getActionMode() {
        return actionMode;
    }

    /**
     * Specifies how actions are to be performed (in sequence of parallel)
     * 
     */
    @JsonProperty("actionMode")
    public void setActionMode(EventsActions.ActionMode actionMode) {
        this.actionMode = actionMode;
    }

    public EventsActions withActionMode(EventsActions.ActionMode actionMode) {
        this.actionMode = actionMode;
        return this;
    }

    /**
     * Actions to be performed.
     * (Required)
     * 
     */
    @JsonProperty("actions")
    public List<Action> getActions() {
        return actions;
    }

    /**
     * Actions to be performed.
     * (Required)
     * 
     */
    @JsonProperty("actions")
    public void setActions(List<Action> actions) {
        this.actions = actions;
    }

    public EventsActions withActions(List<Action> actions) {
        this.actions = actions;
        return this;
    }

    @JsonProperty("eventDataFilter")
    public EventDataFilter getEventDataFilter() {
        return eventDataFilter;
    }

    @JsonProperty("eventDataFilter")
    public void setEventDataFilter(EventDataFilter eventDataFilter) {
        this.eventDataFilter = eventDataFilter;
    }

    public EventsActions withEventDataFilter(EventDataFilter eventDataFilter) {
        this.eventDataFilter = eventDataFilter;
        return this;
    }

    public enum ActionMode {

        SEQUENTIAL("sequential"),
        PARALLEL("parallel");
        private final String value;
        private final static Map<String, EventsActions.ActionMode> CONSTANTS = new HashMap<String, EventsActions.ActionMode>();

        static {
            for (EventsActions.ActionMode c: values()) {
                CONSTANTS.put(c.value, c);
            }
        }

        private ActionMode(String value) {
            this.value = value;
        }

        @Override
        public String toString() {
            return this.value;
        }

        @JsonValue
        public String value() {
            return this.value;
        }

        @JsonCreator
        public static EventsActions.ActionMode fromValue(String value) {
            EventsActions.ActionMode constant = CONSTANTS.get(value);
            if (constant == null) {
                throw new IllegalArgumentException(value);
            } else {
                return constant;
            }
        }

    }

}
